@@ -12,7 +12,7 @@ package Jedi;
 
 use Moo;
 
-our $VERSION = '0.09';    # VERSION
+our $VERSION = '0.10';    # VERSION
 
 use Jedi::Helpers::Scalar;
 use Jedi::Request;
@@ -107,7 +107,7 @@ Jedi - Jedi Web Framework
 
 =head1 VERSION
 
-version 0.09
+version 0.10
 
 =head1 DESCRIPTION
 
@@ -130,7 +130,7 @@ Then your Jedi Apps look likes :
 	package MyApps;
 	use Jedi::Apps;
 
-	sub jedi_apps {
+	sub jedi_app {
 		my ($jedi) = @_;
 
 		$jedi->get('/', $jedi->can('index'));
@@ -158,7 +158,7 @@ You can also plug multiple time the same route or similar, the response will be
 
 A route can check the status to see if another route has already do something. Same think for the body.
 
-You can for instance, create a role, with a before "jedi_apps", that init or add body content, and you route, add more stuff.
+You can for instance, create a role, with a before "jedi_app", that init or add body content, and you route, add more stuff.
 
 Or do an after, that add to the routes, additional content.
 
