@@ -11,11 +11,13 @@ package Jedi::Role::App;
 # ABSTRACT: Jedi App Role
 
 use Moo::Role;
-our $VERSION = '0.09';    # VERSION
+our $VERSION = '0.10';    # VERSION
 use Jedi::Helpers::Scalar;
 use CHI;
 use Carp qw/carp croak/;
 
+requires 'jedi_app';
+
 has '_jedi_routes'  => ( is => 'ro', default => sub { {} } );
 has '_jedi_missing' => ( is => 'ro', default => sub { [] } );
 has '_jedi_routes_cache' => ( is => 'lazy', clearer => 1 );
@@ -117,7 +119,7 @@ Jedi::Role::App - Jedi App Role
 
 =head1 VERSION
 
-version 0.09
+version 0.10
 
 =head1 DESCRIPTION
 
@@ -128,6 +130,8 @@ This role is to apply to your Moo module.
 
 You should use the L<Jedi::App> module.
 
+You module need to defined the sub "jedi_app", the road will call it directly.
+
 =head1 METHODS
 
 =head2 get
